# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: card.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='card.proto',
  package='card',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.cardP\001Z\024biostar/service/card'),
  serialized_pb=_b('\n\ncard.proto\x12\x04\x63\x61rd\x1a\terr.proto\"C\n\x0b\x43SNCardData\x12\x18\n\x04type\x18\x01 \x01(\x0e\x32\n.card.Type\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xd5\x01\n\x0fSmartCardHeader\x12\x11\n\theaderCRC\x18\x01 \x01(\r\x12\x0f\n\x07\x63\x61rdCRC\x18\x02 \x01(\r\x12\x18\n\x04type\x18\x03 \x01(\x0e\x32\n.card.Type\x12\x15\n\rnumOfTemplate\x18\x04 \x01(\r\x12\x14\n\x0ctemplateSize\x18\x05 \x01(\r\x12\x12\n\nissueCount\x18\x06 \x01(\r\x12\x12\n\nduressMask\x18\x07 \x01(\r\x12\x14\n\x0c\x63\x61rdAuthMode\x18\x08 \x01(\r\x12\x19\n\x11useAlphanumericID\x18\t \x01(\x08\"5\n\x13SmartCardCredential\x12\x0b\n\x03PIN\x18\x01 \x01(\x0c\x12\x11\n\ttemplates\x18\x02 \x03(\x0c\"N\n\x10\x41\x63\x63\x65ssOnCardData\x12\x16\n\x0e\x61\x63\x63\x65ssGroupIDs\x18\x01 \x03(\r\x12\x11\n\tstartTime\x18\x02 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x03 \x01(\r\"\xa3\x01\n\rSmartCardData\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.card.SmartCardHeader\x12\x0e\n\x06\x63\x61rdID\x18\x02 \x01(\x0c\x12-\n\ncredential\x18\x03 \x01(\x0b\x32\x19.card.SmartCardCredential\x12,\n\x0c\x61\x63\x63\x65ssOnData\x18\x04 \x01(\x0b\x32\x16.card.AccessOnCardData\"x\n\x08\x43\x61rdData\x12\x18\n\x04type\x18\x01 \x01(\x0e\x32\n.card.Type\x12&\n\x0b\x43SNCardData\x18\x02 \x01(\x0b\x32\x11.card.CSNCardData\x12*\n\rsmartCardData\x18\x03 \x01(\x0b\x32\x13.card.SmartCardData\"\x1f\n\x0bScanRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"0\n\x0cScanResponse\x12 \n\x08\x63\x61rdData\x18\x01 \x01(\x0b\x32\x0e.card.CardData\" \n\x0c\x45raseRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x0f\n\rEraseResponse\"L\n\x0cWriteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12*\n\rsmartCardData\x18\x02 \x01(\x0b\x32\x13.card.SmartCardData\"\x0f\n\rWriteResponse\"Q\n\x0cMifareConfig\x12\x12\n\nprimaryKey\x18\x01 \x01(\x0c\x12\x14\n\x0csecondaryKey\x18\x02 \x01(\x0c\x12\x17\n\x0fstartBlockIndex\x18\x03 \x01(\x05\"Q\n\x0cIClassConfig\x12\x12\n\nprimaryKey\x18\x01 \x01(\x0c\x12\x14\n\x0csecondaryKey\x18\x02 \x01(\x0c\x12\x17\n\x0fstartBlockIndex\x18\x03 \x01(\x05\"\x8d\x01\n\rDESFireConfig\x12\x12\n\nprimaryKey\x18\x01 \x01(\x0c\x12\x14\n\x0csecondaryKey\x18\x02 \x01(\x0c\x12\r\n\x05\x61ppID\x18\x03 \x01(\x0c\x12\x0e\n\x06\x66ileID\x18\x04 \x01(\r\x12\x33\n\x0e\x65ncryptionType\x18\x05 \x01(\x0e\x32\x1b.card.DESFireEncryptionType\"\x90\x01\n\nSEOSConfig\x12\x0e\n\x06OIDADF\x18\x01 \x01(\x0c\x12\x0f\n\x07sizeADF\x18\x02 \x01(\r\x12\x17\n\x0fOIDDataObjectID\x18\x03 \x03(\r\x12\x16\n\x0esizeDataObject\x18\x04 \x03(\r\x12\x16\n\x0eprimaryKeyAuth\x18\x05 \x01(\x0c\x12\x18\n\x10secondaryKeyAuth\x18\x06 \x01(\x0c\"\xc5\x02\n\nCardConfig\x12&\n\tbyteOrder\x18\x01 \x01(\x0e\x32\x13.card.CardByteOrder\x12\x18\n\x10useWiegandFormat\x18\x02 \x01(\x08\x12$\n\x08\x64\x61taType\x18\x03 \x01(\x0e\x32\x12.card.CardDataType\x12\x17\n\x0fuseSecondaryKey\x18\x04 \x01(\x08\x12(\n\x0cmifareConfig\x18\x05 \x01(\x0b\x32\x12.card.MifareConfig\x12(\n\x0ciClassConfig\x18\x06 \x01(\x0b\x32\x12.card.IClassConfig\x12*\n\rDESFireConfig\x18\x07 \x01(\x0b\x32\x13.card.DESFireConfig\x12$\n\nSEOSConfig\x18\x08 \x01(\x0b\x32\x10.card.SEOSConfig\x12\x10\n\x08\x66ormatID\x18\t \x01(\r\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x11GetConfigResponse\x12 \n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x10.card.CardConfig\"F\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.card.CardConfig\"\x13\n\x11SetConfigResponse\"L\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.card.CardConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"3\n\rBlacklistItem\x12\x0e\n\x06\x63\x61rdID\x18\x01 \x01(\x0c\x12\x12\n\nissueCount\x18\x02 \x01(\r\"\'\n\x13GetBlacklistRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\">\n\x14GetBlacklistResponse\x12&\n\tblacklist\x18\x01 \x03(\x0b\x32\x13.card.BlacklistItem\"O\n\x13\x41\x64\x64\x42lacklistRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\tcardInfos\x18\x02 \x03(\x0b\x32\x13.card.BlacklistItem\"\x16\n\x14\x41\x64\x64\x42lacklistResponse\"U\n\x18\x41\x64\x64\x42lacklistMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12&\n\tcardInfos\x18\x02 \x03(\x0b\x32\x13.card.BlacklistItem\"E\n\x19\x41\x64\x64\x42lacklistMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"R\n\x16\x44\x65leteBlacklistRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\tcardInfos\x18\x02 \x03(\x0b\x32\x13.card.BlacklistItem\"\x19\n\x17\x44\x65leteBlacklistResponse\"X\n\x1b\x44\x65leteBlacklistMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12&\n\tcardInfos\x18\x02 \x03(\x0b\x32\x13.card.BlacklistItem\"H\n\x1c\x44\x65leteBlacklistMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"-\n\x19\x44\x65leteAllBlacklistRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1c\n\x1a\x44\x65leteAllBlacklistResponse\"3\n\x1e\x44\x65leteAllBlacklistMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"K\n\x1f\x44\x65leteAllBlacklistMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xef\x01\n\x0c\x43\x61rd1XConfig\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x12\n\nuseCSNOnly\x18\x02 \x01(\x08\x12\x1a\n\x12\x62ioEntryCompatible\x18\x03 \x01(\x08\x12\x17\n\x0fuseSecondaryKey\x18\x04 \x01(\x08\x12\x12\n\nprimaryKey\x18\x05 \x01(\x0c\x12\x14\n\x0csecondaryKey\x18\x06 \x01(\x0c\x12\x10\n\x08\x43ISIndex\x18\x07 \x01(\r\x12\x15\n\rnumOfTemplate\x18\x08 \x01(\r\x12\x14\n\x0ctemplateSize\x18\t \x01(\r\x12\x1b\n\x13templateStartBlocks\x18\n \x03(\r\"&\n\x12Get1XConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x13Get1XConfigResponse\x12\"\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x12.card.Card1XConfig\"J\n\x12Set1XConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.card.Card1XConfig\"\x15\n\x13Set1XConfigResponse\"P\n\x17Set1XConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.card.Card1XConfig\"D\n\x18Set1XConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x12WriteQRCodeRequest\x12\x0e\n\x06QRText\x18\x01 \x01(\t\":\n\x13WriteQRCodeResponse\x12#\n\x08\x63\x61rdData\x18\x01 \x01(\x0b\x32\x11.card.CSNCardData\"2\n\x08QRConfig\x12\x11\n\tuseQRCode\x18\x01 \x01(\x08\x12\x13\n\x0bscanTimeout\x18\x02 \x01(\r\"&\n\x12GetQRConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x13GetQRConfigResponse\x12\x1e\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.card.QRConfig\"F\n\x12SetQRConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.card.QRConfig\"\x15\n\x13SetQRConfigResponse\"L\n\x17SetQRConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.card.QRConfig\"D\n\x18SetQRConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\xd6\x01\n\x04Type\x12\x15\n\x11\x43\x41RD_TYPE_UNKNOWN\x10\x00\x12\x11\n\rCARD_TYPE_CSN\x10\x01\x12\x14\n\x10\x43\x41RD_TYPE_SECURE\x10\x02\x12\x14\n\x10\x43\x41RD_TYPE_ACCESS\x10\x03\x12\x18\n\x14\x43\x41RD_TYPE_CSN_MOBILE\x10\x04\x12\x1c\n\x18\x43\x41RD_TYPE_WIEGAND_MOBILE\x10\x05\x12\x10\n\x0c\x43\x41RD_TYPE_QR\x10\x06\x12\x17\n\x13\x43\x41RD_TYPE_SECURE_QR\x10\x07\x12\x15\n\x11\x43\x41RD_TYPE_WIEGAND\x10\n*6\n\x15\x44\x45SFireEncryptionType\x12\x10\n\x0c\x45NC_DES_3DES\x10\x00\x12\x0b\n\x07\x45NC_AES\x10\x01*!\n\rCardByteOrder\x12\x07\n\x03MSB\x10\x00\x12\x07\n\x03LSB\x10\x01*M\n\x0c\x43\x61rdDataType\x12\x0f\n\x0b\x44\x41TA_BINARY\x10\x00\x12\x0e\n\nDATA_ASCII\x10\x01\x12\x0e\n\nDATA_UTF16\x10\x02\x12\x0c\n\x08\x44\x41TA_BCD\x10\x03\x32\xb0\x0b\n\x04\x43\x61rd\x12-\n\x04Scan\x12\x11.card.ScanRequest\x1a\x12.card.ScanResponse\x12\x30\n\x05\x45rase\x12\x12.card.EraseRequest\x1a\x13.card.EraseResponse\x12\x30\n\x05Write\x12\x12.card.WriteRequest\x1a\x13.card.WriteResponse\x12<\n\tGetConfig\x12\x16.card.GetConfigRequest\x1a\x17.card.GetConfigResponse\x12<\n\tSetConfig\x12\x16.card.SetConfigRequest\x1a\x17.card.SetConfigResponse\x12K\n\x0eSetConfigMulti\x12\x1b.card.SetConfigMultiRequest\x1a\x1c.card.SetConfigMultiResponse\x12\x45\n\x0cGetBlacklist\x12\x19.card.GetBlacklistRequest\x1a\x1a.card.GetBlacklistResponse\x12\x45\n\x0c\x41\x64\x64\x42lacklist\x12\x19.card.AddBlacklistRequest\x1a\x1a.card.AddBlacklistResponse\x12T\n\x11\x41\x64\x64\x42lacklistMulti\x12\x1e.card.AddBlacklistMultiRequest\x1a\x1f.card.AddBlacklistMultiResponse\x12N\n\x0f\x44\x65leteBlacklist\x12\x1c.card.DeleteBlacklistRequest\x1a\x1d.card.DeleteBlacklistResponse\x12]\n\x14\x44\x65leteBlacklistMulti\x12!.card.DeleteBlacklistMultiRequest\x1a\".card.DeleteBlacklistMultiResponse\x12W\n\x12\x44\x65leteAllBlacklist\x12\x1f.card.DeleteAllBlacklistRequest\x1a .card.DeleteAllBlacklistResponse\x12\x66\n\x17\x44\x65leteAllBlacklistMulti\x12$.card.DeleteAllBlacklistMultiRequest\x1a%.card.DeleteAllBlacklistMultiResponse\x12\x42\n\x0bGet1XConfig\x12\x18.card.Get1XConfigRequest\x1a\x19.card.Get1XConfigResponse\x12\x42\n\x0bSet1XConfig\x12\x18.card.Set1XConfigRequest\x1a\x19.card.Set1XConfigResponse\x12Q\n\x10Set1XConfigMulti\x12\x1d.card.Set1XConfigMultiRequest\x1a\x1e.card.Set1XConfigMultiResponse\x12\x42\n\x0bWriteQRCode\x12\x18.card.WriteQRCodeRequest\x1a\x19.card.WriteQRCodeResponse\x12\x42\n\x0bGetQRConfig\x12\x18.card.GetQRConfigRequest\x1a\x19.card.GetQRConfigResponse\x12\x42\n\x0bSetQRConfig\x12\x18.card.SetQRConfigRequest\x1a\x19.card.SetQRConfigResponse\x12Q\n\x10SetQRConfigMulti\x12\x1d.card.SetQRConfigMultiRequest\x1a\x1e.card.SetQRConfigMultiResponseB1\n\x17\x63om.supremainc.sdk.cardP\x01Z\x14\x62iostar/service/cardb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='card.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_CSN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_SECURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_ACCESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_CSN_MOBILE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_WIEGAND_MOBILE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_QR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_SECURE_QR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TYPE_WIEGAND', index=8, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4069,
  serialized_end=4283,
)
_sym_db.RegisterEnumDescriptor(_TYPE)

Type = enum_type_wrapper.EnumTypeWrapper(_TYPE)
_DESFIREENCRYPTIONTYPE = _descriptor.EnumDescriptor(
  name='DESFireEncryptionType',
  full_name='card.DESFireEncryptionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENC_DES_3DES', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENC_AES', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4285,
  serialized_end=4339,
)
_sym_db.RegisterEnumDescriptor(_DESFIREENCRYPTIONTYPE)

DESFireEncryptionType = enum_type_wrapper.EnumTypeWrapper(_DESFIREENCRYPTIONTYPE)
_CARDBYTEORDER = _descriptor.EnumDescriptor(
  name='CardByteOrder',
  full_name='card.CardByteOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSB', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LSB', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4341,
  serialized_end=4374,
)
_sym_db.RegisterEnumDescriptor(_CARDBYTEORDER)

CardByteOrder = enum_type_wrapper.EnumTypeWrapper(_CARDBYTEORDER)
_CARDDATATYPE = _descriptor.EnumDescriptor(
  name='CardDataType',
  full_name='card.CardDataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_BINARY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_ASCII', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_UTF16', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_BCD', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4376,
  serialized_end=4453,
)
_sym_db.RegisterEnumDescriptor(_CARDDATATYPE)

CardDataType = enum_type_wrapper.EnumTypeWrapper(_CARDDATATYPE)
CARD_TYPE_UNKNOWN = 0
CARD_TYPE_CSN = 1
CARD_TYPE_SECURE = 2
CARD_TYPE_ACCESS = 3
CARD_TYPE_CSN_MOBILE = 4
CARD_TYPE_WIEGAND_MOBILE = 5
CARD_TYPE_QR = 6
CARD_TYPE_SECURE_QR = 7
CARD_TYPE_WIEGAND = 10
ENC_DES_3DES = 0
ENC_AES = 1
MSB = 0
LSB = 1
DATA_BINARY = 0
DATA_ASCII = 1
DATA_UTF16 = 2
DATA_BCD = 3



_CSNCARDDATA = _descriptor.Descriptor(
  name='CSNCardData',
  full_name='card.CSNCardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='card.CSNCardData.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='card.CSNCardData.size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='card.CSNCardData.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=98,
)


_SMARTCARDHEADER = _descriptor.Descriptor(
  name='SmartCardHeader',
  full_name='card.SmartCardHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headerCRC', full_name='card.SmartCardHeader.headerCRC', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardCRC', full_name='card.SmartCardHeader.cardCRC', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='card.SmartCardHeader.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numOfTemplate', full_name='card.SmartCardHeader.numOfTemplate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateSize', full_name='card.SmartCardHeader.templateSize', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueCount', full_name='card.SmartCardHeader.issueCount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duressMask', full_name='card.SmartCardHeader.duressMask', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardAuthMode', full_name='card.SmartCardHeader.cardAuthMode', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useAlphanumericID', full_name='card.SmartCardHeader.useAlphanumericID', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=314,
)


_SMARTCARDCREDENTIAL = _descriptor.Descriptor(
  name='SmartCardCredential',
  full_name='card.SmartCardCredential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='PIN', full_name='card.SmartCardCredential.PIN', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templates', full_name='card.SmartCardCredential.templates', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=369,
)


_ACCESSONCARDDATA = _descriptor.Descriptor(
  name='AccessOnCardData',
  full_name='card.AccessOnCardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accessGroupIDs', full_name='card.AccessOnCardData.accessGroupIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='card.AccessOnCardData.startTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='card.AccessOnCardData.endTime', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=449,
)


_SMARTCARDDATA = _descriptor.Descriptor(
  name='SmartCardData',
  full_name='card.SmartCardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='card.SmartCardData.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardID', full_name='card.SmartCardData.cardID', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='credential', full_name='card.SmartCardData.credential', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessOnData', full_name='card.SmartCardData.accessOnData', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=615,
)


_CARDDATA = _descriptor.Descriptor(
  name='CardData',
  full_name='card.CardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='card.CardData.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='CSNCardData', full_name='card.CardData.CSNCardData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smartCardData', full_name='card.CardData.smartCardData', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=737,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='card.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.ScanRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=770,
)


_SCANRESPONSE = _descriptor.Descriptor(
  name='ScanResponse',
  full_name='card.ScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cardData', full_name='card.ScanResponse.cardData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=820,
)


_ERASEREQUEST = _descriptor.Descriptor(
  name='EraseRequest',
  full_name='card.EraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.EraseRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=854,
)


_ERASERESPONSE = _descriptor.Descriptor(
  name='EraseResponse',
  full_name='card.EraseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=871,
)


_WRITEREQUEST = _descriptor.Descriptor(
  name='WriteRequest',
  full_name='card.WriteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.WriteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smartCardData', full_name='card.WriteRequest.smartCardData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=949,
)


_WRITERESPONSE = _descriptor.Descriptor(
  name='WriteResponse',
  full_name='card.WriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=966,
)


_MIFARECONFIG = _descriptor.Descriptor(
  name='MifareConfig',
  full_name='card.MifareConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primaryKey', full_name='card.MifareConfig.primaryKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondaryKey', full_name='card.MifareConfig.secondaryKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startBlockIndex', full_name='card.MifareConfig.startBlockIndex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1049,
)


_ICLASSCONFIG = _descriptor.Descriptor(
  name='IClassConfig',
  full_name='card.IClassConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primaryKey', full_name='card.IClassConfig.primaryKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondaryKey', full_name='card.IClassConfig.secondaryKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startBlockIndex', full_name='card.IClassConfig.startBlockIndex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1132,
)


_DESFIRECONFIG = _descriptor.Descriptor(
  name='DESFireConfig',
  full_name='card.DESFireConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primaryKey', full_name='card.DESFireConfig.primaryKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondaryKey', full_name='card.DESFireConfig.secondaryKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appID', full_name='card.DESFireConfig.appID', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileID', full_name='card.DESFireConfig.fileID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptionType', full_name='card.DESFireConfig.encryptionType', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1276,
)


_SEOSCONFIG = _descriptor.Descriptor(
  name='SEOSConfig',
  full_name='card.SEOSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='OIDADF', full_name='card.SEOSConfig.OIDADF', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeADF', full_name='card.SEOSConfig.sizeADF', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='OIDDataObjectID', full_name='card.SEOSConfig.OIDDataObjectID', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeDataObject', full_name='card.SEOSConfig.sizeDataObject', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primaryKeyAuth', full_name='card.SEOSConfig.primaryKeyAuth', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondaryKeyAuth', full_name='card.SEOSConfig.secondaryKeyAuth', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1423,
)


_CARDCONFIG = _descriptor.Descriptor(
  name='CardConfig',
  full_name='card.CardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='byteOrder', full_name='card.CardConfig.byteOrder', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useWiegandFormat', full_name='card.CardConfig.useWiegandFormat', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataType', full_name='card.CardConfig.dataType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useSecondaryKey', full_name='card.CardConfig.useSecondaryKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mifareConfig', full_name='card.CardConfig.mifareConfig', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iClassConfig', full_name='card.CardConfig.iClassConfig', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DESFireConfig', full_name='card.CardConfig.DESFireConfig', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SEOSConfig', full_name='card.CardConfig.SEOSConfig', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatID', full_name='card.CardConfig.formatID', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1426,
  serialized_end=1751,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='card.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1753,
  serialized_end=1789,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='card.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='card.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1791,
  serialized_end=1844,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='card.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=1916,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='card.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1937,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='card.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1939,
  serialized_end=2015,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='card.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2083,
)


_BLACKLISTITEM = _descriptor.Descriptor(
  name='BlacklistItem',
  full_name='card.BlacklistItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cardID', full_name='card.BlacklistItem.cardID', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueCount', full_name='card.BlacklistItem.issueCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2085,
  serialized_end=2136,
)


_GETBLACKLISTREQUEST = _descriptor.Descriptor(
  name='GetBlacklistRequest',
  full_name='card.GetBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.GetBlacklistRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2177,
)


_GETBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='GetBlacklistResponse',
  full_name='card.GetBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blacklist', full_name='card.GetBlacklistResponse.blacklist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2179,
  serialized_end=2241,
)


_ADDBLACKLISTREQUEST = _descriptor.Descriptor(
  name='AddBlacklistRequest',
  full_name='card.AddBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.AddBlacklistRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardInfos', full_name='card.AddBlacklistRequest.cardInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2243,
  serialized_end=2322,
)


_ADDBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='AddBlacklistResponse',
  full_name='card.AddBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=2346,
)


_ADDBLACKLISTMULTIREQUEST = _descriptor.Descriptor(
  name='AddBlacklistMultiRequest',
  full_name='card.AddBlacklistMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.AddBlacklistMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardInfos', full_name='card.AddBlacklistMultiRequest.cardInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2433,
)


_ADDBLACKLISTMULTIRESPONSE = _descriptor.Descriptor(
  name='AddBlacklistMultiResponse',
  full_name='card.AddBlacklistMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.AddBlacklistMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2435,
  serialized_end=2504,
)


_DELETEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='DeleteBlacklistRequest',
  full_name='card.DeleteBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.DeleteBlacklistRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardInfos', full_name='card.DeleteBlacklistRequest.cardInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2588,
)


_DELETEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='DeleteBlacklistResponse',
  full_name='card.DeleteBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2590,
  serialized_end=2615,
)


_DELETEBLACKLISTMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteBlacklistMultiRequest',
  full_name='card.DeleteBlacklistMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.DeleteBlacklistMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardInfos', full_name='card.DeleteBlacklistMultiRequest.cardInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2617,
  serialized_end=2705,
)


_DELETEBLACKLISTMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteBlacklistMultiResponse',
  full_name='card.DeleteBlacklistMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.DeleteBlacklistMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2707,
  serialized_end=2779,
)


_DELETEALLBLACKLISTREQUEST = _descriptor.Descriptor(
  name='DeleteAllBlacklistRequest',
  full_name='card.DeleteAllBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.DeleteAllBlacklistRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2781,
  serialized_end=2826,
)


_DELETEALLBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='DeleteAllBlacklistResponse',
  full_name='card.DeleteAllBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=2856,
)


_DELETEALLBLACKLISTMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllBlacklistMultiRequest',
  full_name='card.DeleteAllBlacklistMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.DeleteAllBlacklistMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2858,
  serialized_end=2909,
)


_DELETEALLBLACKLISTMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllBlacklistMultiResponse',
  full_name='card.DeleteAllBlacklistMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.DeleteAllBlacklistMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2911,
  serialized_end=2986,
)


_CARD1XCONFIG = _descriptor.Descriptor(
  name='Card1XConfig',
  full_name='card.Card1XConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='card.Card1XConfig.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useCSNOnly', full_name='card.Card1XConfig.useCSNOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioEntryCompatible', full_name='card.Card1XConfig.bioEntryCompatible', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useSecondaryKey', full_name='card.Card1XConfig.useSecondaryKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primaryKey', full_name='card.Card1XConfig.primaryKey', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondaryKey', full_name='card.Card1XConfig.secondaryKey', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='CISIndex', full_name='card.Card1XConfig.CISIndex', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numOfTemplate', full_name='card.Card1XConfig.numOfTemplate', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateSize', full_name='card.Card1XConfig.templateSize', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateStartBlocks', full_name='card.Card1XConfig.templateStartBlocks', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2989,
  serialized_end=3228,
)


_GET1XCONFIGREQUEST = _descriptor.Descriptor(
  name='Get1XConfigRequest',
  full_name='card.Get1XConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.Get1XConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3230,
  serialized_end=3268,
)


_GET1XCONFIGRESPONSE = _descriptor.Descriptor(
  name='Get1XConfigResponse',
  full_name='card.Get1XConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='card.Get1XConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3270,
  serialized_end=3327,
)


_SET1XCONFIGREQUEST = _descriptor.Descriptor(
  name='Set1XConfigRequest',
  full_name='card.Set1XConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.Set1XConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.Set1XConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3329,
  serialized_end=3403,
)


_SET1XCONFIGRESPONSE = _descriptor.Descriptor(
  name='Set1XConfigResponse',
  full_name='card.Set1XConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3405,
  serialized_end=3426,
)


_SET1XCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='Set1XConfigMultiRequest',
  full_name='card.Set1XConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.Set1XConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.Set1XConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3428,
  serialized_end=3508,
)


_SET1XCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='Set1XConfigMultiResponse',
  full_name='card.Set1XConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.Set1XConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3510,
  serialized_end=3578,
)


_WRITEQRCODEREQUEST = _descriptor.Descriptor(
  name='WriteQRCodeRequest',
  full_name='card.WriteQRCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='QRText', full_name='card.WriteQRCodeRequest.QRText', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3580,
  serialized_end=3616,
)


_WRITEQRCODERESPONSE = _descriptor.Descriptor(
  name='WriteQRCodeResponse',
  full_name='card.WriteQRCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cardData', full_name='card.WriteQRCodeResponse.cardData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3676,
)


_QRCONFIG = _descriptor.Descriptor(
  name='QRConfig',
  full_name='card.QRConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='useQRCode', full_name='card.QRConfig.useQRCode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanTimeout', full_name='card.QRConfig.scanTimeout', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3728,
)


_GETQRCONFIGREQUEST = _descriptor.Descriptor(
  name='GetQRConfigRequest',
  full_name='card.GetQRConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.GetQRConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3730,
  serialized_end=3768,
)


_GETQRCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetQRConfigResponse',
  full_name='card.GetQRConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='card.GetQRConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3770,
  serialized_end=3823,
)


_SETQRCONFIGREQUEST = _descriptor.Descriptor(
  name='SetQRConfigRequest',
  full_name='card.SetQRConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='card.SetQRConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.SetQRConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3825,
  serialized_end=3895,
)


_SETQRCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetQRConfigResponse',
  full_name='card.SetQRConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3897,
  serialized_end=3918,
)


_SETQRCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetQRConfigMultiRequest',
  full_name='card.SetQRConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='card.SetQRConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='card.SetQRConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3920,
  serialized_end=3996,
)


_SETQRCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetQRConfigMultiResponse',
  full_name='card.SetQRConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='card.SetQRConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3998,
  serialized_end=4066,
)

_CSNCARDDATA.fields_by_name['type'].enum_type = _TYPE
_SMARTCARDHEADER.fields_by_name['type'].enum_type = _TYPE
_SMARTCARDDATA.fields_by_name['header'].message_type = _SMARTCARDHEADER
_SMARTCARDDATA.fields_by_name['credential'].message_type = _SMARTCARDCREDENTIAL
_SMARTCARDDATA.fields_by_name['accessOnData'].message_type = _ACCESSONCARDDATA
_CARDDATA.fields_by_name['type'].enum_type = _TYPE
_CARDDATA.fields_by_name['CSNCardData'].message_type = _CSNCARDDATA
_CARDDATA.fields_by_name['smartCardData'].message_type = _SMARTCARDDATA
_SCANRESPONSE.fields_by_name['cardData'].message_type = _CARDDATA
_WRITEREQUEST.fields_by_name['smartCardData'].message_type = _SMARTCARDDATA
_DESFIRECONFIG.fields_by_name['encryptionType'].enum_type = _DESFIREENCRYPTIONTYPE
_CARDCONFIG.fields_by_name['byteOrder'].enum_type = _CARDBYTEORDER
_CARDCONFIG.fields_by_name['dataType'].enum_type = _CARDDATATYPE
_CARDCONFIG.fields_by_name['mifareConfig'].message_type = _MIFARECONFIG
_CARDCONFIG.fields_by_name['iClassConfig'].message_type = _ICLASSCONFIG
_CARDCONFIG.fields_by_name['DESFireConfig'].message_type = _DESFIRECONFIG
_CARDCONFIG.fields_by_name['SEOSConfig'].message_type = _SEOSCONFIG
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _CARDCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _CARDCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _CARDCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETBLACKLISTRESPONSE.fields_by_name['blacklist'].message_type = _BLACKLISTITEM
_ADDBLACKLISTREQUEST.fields_by_name['cardInfos'].message_type = _BLACKLISTITEM
_ADDBLACKLISTMULTIREQUEST.fields_by_name['cardInfos'].message_type = _BLACKLISTITEM
_ADDBLACKLISTMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEBLACKLISTREQUEST.fields_by_name['cardInfos'].message_type = _BLACKLISTITEM
_DELETEBLACKLISTMULTIREQUEST.fields_by_name['cardInfos'].message_type = _BLACKLISTITEM
_DELETEBLACKLISTMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLBLACKLISTMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GET1XCONFIGRESPONSE.fields_by_name['config'].message_type = _CARD1XCONFIG
_SET1XCONFIGREQUEST.fields_by_name['config'].message_type = _CARD1XCONFIG
_SET1XCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _CARD1XCONFIG
_SET1XCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_WRITEQRCODERESPONSE.fields_by_name['cardData'].message_type = _CSNCARDDATA
_GETQRCONFIGRESPONSE.fields_by_name['config'].message_type = _QRCONFIG
_SETQRCONFIGREQUEST.fields_by_name['config'].message_type = _QRCONFIG
_SETQRCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _QRCONFIG
_SETQRCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['CSNCardData'] = _CSNCARDDATA
DESCRIPTOR.message_types_by_name['SmartCardHeader'] = _SMARTCARDHEADER
DESCRIPTOR.message_types_by_name['SmartCardCredential'] = _SMARTCARDCREDENTIAL
DESCRIPTOR.message_types_by_name['AccessOnCardData'] = _ACCESSONCARDDATA
DESCRIPTOR.message_types_by_name['SmartCardData'] = _SMARTCARDDATA
DESCRIPTOR.message_types_by_name['CardData'] = _CARDDATA
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ScanResponse'] = _SCANRESPONSE
DESCRIPTOR.message_types_by_name['EraseRequest'] = _ERASEREQUEST
DESCRIPTOR.message_types_by_name['EraseResponse'] = _ERASERESPONSE
DESCRIPTOR.message_types_by_name['WriteRequest'] = _WRITEREQUEST
DESCRIPTOR.message_types_by_name['WriteResponse'] = _WRITERESPONSE
DESCRIPTOR.message_types_by_name['MifareConfig'] = _MIFARECONFIG
DESCRIPTOR.message_types_by_name['IClassConfig'] = _ICLASSCONFIG
DESCRIPTOR.message_types_by_name['DESFireConfig'] = _DESFIRECONFIG
DESCRIPTOR.message_types_by_name['SEOSConfig'] = _SEOSCONFIG
DESCRIPTOR.message_types_by_name['CardConfig'] = _CARDCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['BlacklistItem'] = _BLACKLISTITEM
DESCRIPTOR.message_types_by_name['GetBlacklistRequest'] = _GETBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['GetBlacklistResponse'] = _GETBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddBlacklistRequest'] = _ADDBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['AddBlacklistResponse'] = _ADDBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddBlacklistMultiRequest'] = _ADDBLACKLISTMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddBlacklistMultiResponse'] = _ADDBLACKLISTMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBlacklistRequest'] = _DELETEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['DeleteBlacklistResponse'] = _DELETEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBlacklistMultiRequest'] = _DELETEBLACKLISTMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteBlacklistMultiResponse'] = _DELETEBLACKLISTMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllBlacklistRequest'] = _DELETEALLBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllBlacklistResponse'] = _DELETEALLBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllBlacklistMultiRequest'] = _DELETEALLBLACKLISTMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllBlacklistMultiResponse'] = _DELETEALLBLACKLISTMULTIRESPONSE
DESCRIPTOR.message_types_by_name['Card1XConfig'] = _CARD1XCONFIG
DESCRIPTOR.message_types_by_name['Get1XConfigRequest'] = _GET1XCONFIGREQUEST
DESCRIPTOR.message_types_by_name['Get1XConfigResponse'] = _GET1XCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['Set1XConfigRequest'] = _SET1XCONFIGREQUEST
DESCRIPTOR.message_types_by_name['Set1XConfigResponse'] = _SET1XCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['Set1XConfigMultiRequest'] = _SET1XCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['Set1XConfigMultiResponse'] = _SET1XCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['WriteQRCodeRequest'] = _WRITEQRCODEREQUEST
DESCRIPTOR.message_types_by_name['WriteQRCodeResponse'] = _WRITEQRCODERESPONSE
DESCRIPTOR.message_types_by_name['QRConfig'] = _QRCONFIG
DESCRIPTOR.message_types_by_name['GetQRConfigRequest'] = _GETQRCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetQRConfigResponse'] = _GETQRCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetQRConfigRequest'] = _SETQRCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetQRConfigResponse'] = _SETQRCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetQRConfigMultiRequest'] = _SETQRCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetQRConfigMultiResponse'] = _SETQRCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['Type'] = _TYPE
DESCRIPTOR.enum_types_by_name['DESFireEncryptionType'] = _DESFIREENCRYPTIONTYPE
DESCRIPTOR.enum_types_by_name['CardByteOrder'] = _CARDBYTEORDER
DESCRIPTOR.enum_types_by_name['CardDataType'] = _CARDDATATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CSNCardData = _reflection.GeneratedProtocolMessageType('CSNCardData', (_message.Message,), dict(
  DESCRIPTOR = _CSNCARDDATA,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.CSNCardData)
  ))
_sym_db.RegisterMessage(CSNCardData)

SmartCardHeader = _reflection.GeneratedProtocolMessageType('SmartCardHeader', (_message.Message,), dict(
  DESCRIPTOR = _SMARTCARDHEADER,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SmartCardHeader)
  ))
_sym_db.RegisterMessage(SmartCardHeader)

SmartCardCredential = _reflection.GeneratedProtocolMessageType('SmartCardCredential', (_message.Message,), dict(
  DESCRIPTOR = _SMARTCARDCREDENTIAL,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SmartCardCredential)
  ))
_sym_db.RegisterMessage(SmartCardCredential)

AccessOnCardData = _reflection.GeneratedProtocolMessageType('AccessOnCardData', (_message.Message,), dict(
  DESCRIPTOR = _ACCESSONCARDDATA,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.AccessOnCardData)
  ))
_sym_db.RegisterMessage(AccessOnCardData)

SmartCardData = _reflection.GeneratedProtocolMessageType('SmartCardData', (_message.Message,), dict(
  DESCRIPTOR = _SMARTCARDDATA,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SmartCardData)
  ))
_sym_db.RegisterMessage(SmartCardData)

CardData = _reflection.GeneratedProtocolMessageType('CardData', (_message.Message,), dict(
  DESCRIPTOR = _CARDDATA,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.CardData)
  ))
_sym_db.RegisterMessage(CardData)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCANREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.ScanRequest)
  ))
_sym_db.RegisterMessage(ScanRequest)

ScanResponse = _reflection.GeneratedProtocolMessageType('ScanResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCANRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.ScanResponse)
  ))
_sym_db.RegisterMessage(ScanResponse)

EraseRequest = _reflection.GeneratedProtocolMessageType('EraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _ERASEREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.EraseRequest)
  ))
_sym_db.RegisterMessage(EraseRequest)

EraseResponse = _reflection.GeneratedProtocolMessageType('EraseResponse', (_message.Message,), dict(
  DESCRIPTOR = _ERASERESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.EraseResponse)
  ))
_sym_db.RegisterMessage(EraseResponse)

WriteRequest = _reflection.GeneratedProtocolMessageType('WriteRequest', (_message.Message,), dict(
  DESCRIPTOR = _WRITEREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.WriteRequest)
  ))
_sym_db.RegisterMessage(WriteRequest)

WriteResponse = _reflection.GeneratedProtocolMessageType('WriteResponse', (_message.Message,), dict(
  DESCRIPTOR = _WRITERESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.WriteResponse)
  ))
_sym_db.RegisterMessage(WriteResponse)

MifareConfig = _reflection.GeneratedProtocolMessageType('MifareConfig', (_message.Message,), dict(
  DESCRIPTOR = _MIFARECONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.MifareConfig)
  ))
_sym_db.RegisterMessage(MifareConfig)

IClassConfig = _reflection.GeneratedProtocolMessageType('IClassConfig', (_message.Message,), dict(
  DESCRIPTOR = _ICLASSCONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.IClassConfig)
  ))
_sym_db.RegisterMessage(IClassConfig)

DESFireConfig = _reflection.GeneratedProtocolMessageType('DESFireConfig', (_message.Message,), dict(
  DESCRIPTOR = _DESFIRECONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DESFireConfig)
  ))
_sym_db.RegisterMessage(DESFireConfig)

SEOSConfig = _reflection.GeneratedProtocolMessageType('SEOSConfig', (_message.Message,), dict(
  DESCRIPTOR = _SEOSCONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SEOSConfig)
  ))
_sym_db.RegisterMessage(SEOSConfig)

CardConfig = _reflection.GeneratedProtocolMessageType('CardConfig', (_message.Message,), dict(
  DESCRIPTOR = _CARDCONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.CardConfig)
  ))
_sym_db.RegisterMessage(CardConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

BlacklistItem = _reflection.GeneratedProtocolMessageType('BlacklistItem', (_message.Message,), dict(
  DESCRIPTOR = _BLACKLISTITEM,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.BlacklistItem)
  ))
_sym_db.RegisterMessage(BlacklistItem)

GetBlacklistRequest = _reflection.GeneratedProtocolMessageType('GetBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBLACKLISTREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetBlacklistRequest)
  ))
_sym_db.RegisterMessage(GetBlacklistRequest)

GetBlacklistResponse = _reflection.GeneratedProtocolMessageType('GetBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETBLACKLISTRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetBlacklistResponse)
  ))
_sym_db.RegisterMessage(GetBlacklistResponse)

AddBlacklistRequest = _reflection.GeneratedProtocolMessageType('AddBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLACKLISTREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.AddBlacklistRequest)
  ))
_sym_db.RegisterMessage(AddBlacklistRequest)

AddBlacklistResponse = _reflection.GeneratedProtocolMessageType('AddBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLACKLISTRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.AddBlacklistResponse)
  ))
_sym_db.RegisterMessage(AddBlacklistResponse)

AddBlacklistMultiRequest = _reflection.GeneratedProtocolMessageType('AddBlacklistMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLACKLISTMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.AddBlacklistMultiRequest)
  ))
_sym_db.RegisterMessage(AddBlacklistMultiRequest)

AddBlacklistMultiResponse = _reflection.GeneratedProtocolMessageType('AddBlacklistMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLACKLISTMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.AddBlacklistMultiResponse)
  ))
_sym_db.RegisterMessage(AddBlacklistMultiResponse)

DeleteBlacklistRequest = _reflection.GeneratedProtocolMessageType('DeleteBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEBLACKLISTREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteBlacklistRequest)
  ))
_sym_db.RegisterMessage(DeleteBlacklistRequest)

DeleteBlacklistResponse = _reflection.GeneratedProtocolMessageType('DeleteBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEBLACKLISTRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteBlacklistResponse)
  ))
_sym_db.RegisterMessage(DeleteBlacklistResponse)

DeleteBlacklistMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteBlacklistMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEBLACKLISTMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteBlacklistMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteBlacklistMultiRequest)

DeleteBlacklistMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteBlacklistMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEBLACKLISTMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteBlacklistMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteBlacklistMultiResponse)

DeleteAllBlacklistRequest = _reflection.GeneratedProtocolMessageType('DeleteAllBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLBLACKLISTREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteAllBlacklistRequest)
  ))
_sym_db.RegisterMessage(DeleteAllBlacklistRequest)

DeleteAllBlacklistResponse = _reflection.GeneratedProtocolMessageType('DeleteAllBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLBLACKLISTRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteAllBlacklistResponse)
  ))
_sym_db.RegisterMessage(DeleteAllBlacklistResponse)

DeleteAllBlacklistMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllBlacklistMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLBLACKLISTMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteAllBlacklistMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllBlacklistMultiRequest)

DeleteAllBlacklistMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllBlacklistMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLBLACKLISTMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.DeleteAllBlacklistMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllBlacklistMultiResponse)

Card1XConfig = _reflection.GeneratedProtocolMessageType('Card1XConfig', (_message.Message,), dict(
  DESCRIPTOR = _CARD1XCONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Card1XConfig)
  ))
_sym_db.RegisterMessage(Card1XConfig)

Get1XConfigRequest = _reflection.GeneratedProtocolMessageType('Get1XConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GET1XCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Get1XConfigRequest)
  ))
_sym_db.RegisterMessage(Get1XConfigRequest)

Get1XConfigResponse = _reflection.GeneratedProtocolMessageType('Get1XConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GET1XCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Get1XConfigResponse)
  ))
_sym_db.RegisterMessage(Get1XConfigResponse)

Set1XConfigRequest = _reflection.GeneratedProtocolMessageType('Set1XConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SET1XCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Set1XConfigRequest)
  ))
_sym_db.RegisterMessage(Set1XConfigRequest)

Set1XConfigResponse = _reflection.GeneratedProtocolMessageType('Set1XConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SET1XCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Set1XConfigResponse)
  ))
_sym_db.RegisterMessage(Set1XConfigResponse)

Set1XConfigMultiRequest = _reflection.GeneratedProtocolMessageType('Set1XConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SET1XCONFIGMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Set1XConfigMultiRequest)
  ))
_sym_db.RegisterMessage(Set1XConfigMultiRequest)

Set1XConfigMultiResponse = _reflection.GeneratedProtocolMessageType('Set1XConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SET1XCONFIGMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.Set1XConfigMultiResponse)
  ))
_sym_db.RegisterMessage(Set1XConfigMultiResponse)

WriteQRCodeRequest = _reflection.GeneratedProtocolMessageType('WriteQRCodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _WRITEQRCODEREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.WriteQRCodeRequest)
  ))
_sym_db.RegisterMessage(WriteQRCodeRequest)

WriteQRCodeResponse = _reflection.GeneratedProtocolMessageType('WriteQRCodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _WRITEQRCODERESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.WriteQRCodeResponse)
  ))
_sym_db.RegisterMessage(WriteQRCodeResponse)

QRConfig = _reflection.GeneratedProtocolMessageType('QRConfig', (_message.Message,), dict(
  DESCRIPTOR = _QRCONFIG,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.QRConfig)
  ))
_sym_db.RegisterMessage(QRConfig)

GetQRConfigRequest = _reflection.GeneratedProtocolMessageType('GetQRConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETQRCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetQRConfigRequest)
  ))
_sym_db.RegisterMessage(GetQRConfigRequest)

GetQRConfigResponse = _reflection.GeneratedProtocolMessageType('GetQRConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETQRCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.GetQRConfigResponse)
  ))
_sym_db.RegisterMessage(GetQRConfigResponse)

SetQRConfigRequest = _reflection.GeneratedProtocolMessageType('SetQRConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETQRCONFIGREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetQRConfigRequest)
  ))
_sym_db.RegisterMessage(SetQRConfigRequest)

SetQRConfigResponse = _reflection.GeneratedProtocolMessageType('SetQRConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETQRCONFIGRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetQRConfigResponse)
  ))
_sym_db.RegisterMessage(SetQRConfigResponse)

SetQRConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetQRConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETQRCONFIGMULTIREQUEST,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetQRConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetQRConfigMultiRequest)

SetQRConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetQRConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETQRCONFIGMULTIRESPONSE,
  __module__ = 'card_pb2'
  # @@protoc_insertion_point(class_scope:card.SetQRConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetQRConfigMultiResponse)


DESCRIPTOR._options = None

_CARD = _descriptor.ServiceDescriptor(
  name='Card',
  full_name='card.Card',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=4456,
  serialized_end=5912,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='card.Card.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_SCANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Erase',
    full_name='card.Card.Erase',
    index=1,
    containing_service=None,
    input_type=_ERASEREQUEST,
    output_type=_ERASERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Write',
    full_name='card.Card.Write',
    index=2,
    containing_service=None,
    input_type=_WRITEREQUEST,
    output_type=_WRITERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='card.Card.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='card.Card.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='card.Card.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlacklist',
    full_name='card.Card.GetBlacklist',
    index=6,
    containing_service=None,
    input_type=_GETBLACKLISTREQUEST,
    output_type=_GETBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddBlacklist',
    full_name='card.Card.AddBlacklist',
    index=7,
    containing_service=None,
    input_type=_ADDBLACKLISTREQUEST,
    output_type=_ADDBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddBlacklistMulti',
    full_name='card.Card.AddBlacklistMulti',
    index=8,
    containing_service=None,
    input_type=_ADDBLACKLISTMULTIREQUEST,
    output_type=_ADDBLACKLISTMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBlacklist',
    full_name='card.Card.DeleteBlacklist',
    index=9,
    containing_service=None,
    input_type=_DELETEBLACKLISTREQUEST,
    output_type=_DELETEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBlacklistMulti',
    full_name='card.Card.DeleteBlacklistMulti',
    index=10,
    containing_service=None,
    input_type=_DELETEBLACKLISTMULTIREQUEST,
    output_type=_DELETEBLACKLISTMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllBlacklist',
    full_name='card.Card.DeleteAllBlacklist',
    index=11,
    containing_service=None,
    input_type=_DELETEALLBLACKLISTREQUEST,
    output_type=_DELETEALLBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllBlacklistMulti',
    full_name='card.Card.DeleteAllBlacklistMulti',
    index=12,
    containing_service=None,
    input_type=_DELETEALLBLACKLISTMULTIREQUEST,
    output_type=_DELETEALLBLACKLISTMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get1XConfig',
    full_name='card.Card.Get1XConfig',
    index=13,
    containing_service=None,
    input_type=_GET1XCONFIGREQUEST,
    output_type=_GET1XCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set1XConfig',
    full_name='card.Card.Set1XConfig',
    index=14,
    containing_service=None,
    input_type=_SET1XCONFIGREQUEST,
    output_type=_SET1XCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set1XConfigMulti',
    full_name='card.Card.Set1XConfigMulti',
    index=15,
    containing_service=None,
    input_type=_SET1XCONFIGMULTIREQUEST,
    output_type=_SET1XCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WriteQRCode',
    full_name='card.Card.WriteQRCode',
    index=16,
    containing_service=None,
    input_type=_WRITEQRCODEREQUEST,
    output_type=_WRITEQRCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetQRConfig',
    full_name='card.Card.GetQRConfig',
    index=17,
    containing_service=None,
    input_type=_GETQRCONFIGREQUEST,
    output_type=_GETQRCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetQRConfig',
    full_name='card.Card.SetQRConfig',
    index=18,
    containing_service=None,
    input_type=_SETQRCONFIGREQUEST,
    output_type=_SETQRCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetQRConfigMulti',
    full_name='card.Card.SetQRConfigMulti',
    index=19,
    containing_service=None,
    input_type=_SETQRCONFIGMULTIREQUEST,
    output_type=_SETQRCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CARD)

DESCRIPTOR.services_by_name['Card'] = _CARD

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import server_pb2 as server__pb2


class ServerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Subscribe = channel.unary_stream(
        '/server.Server/Subscribe',
        request_serializer=server__pb2.SubscribeRequest.SerializeToString,
        response_deserializer=server__pb2.ServerRequest.FromString,
        )
    self.Unsubscribe = channel.unary_unary(
        '/server.Server/Unsubscribe',
        request_serializer=server__pb2.UnsubscribeRequest.SerializeToString,
        response_deserializer=server__pb2.UnsubscribeResponse.FromString,
        )
    self.HandleVerify = channel.unary_unary(
        '/server.Server/HandleVerify',
        request_serializer=server__pb2.HandleVerifyRequest.SerializeToString,
        response_deserializer=server__pb2.HandleVerifyResponse.FromString,
        )
    self.HandleIdentify = channel.unary_unary(
        '/server.Server/HandleIdentify',
        request_serializer=server__pb2.HandleIdentifyRequest.SerializeToString,
        response_deserializer=server__pb2.HandleIdentifyResponse.FromString,
        )
    self.HandleGlobalAPB = channel.unary_unary(
        '/server.Server/HandleGlobalAPB',
        request_serializer=server__pb2.HandleGlobalAPBRequest.SerializeToString,
        response_deserializer=server__pb2.HandleGlobalAPBResponse.FromString,
        )
    self.HandleUserPhrase = channel.unary_unary(
        '/server.Server/HandleUserPhrase',
        request_serializer=server__pb2.HandleUserPhraseRequest.SerializeToString,
        response_deserializer=server__pb2.HandleUserPhraseResponse.FromString,
        )


class ServerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Subscribe(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Unsubscribe(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandleVerify(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandleIdentify(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandleGlobalAPB(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandleUserPhrase(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ServerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Subscribe': grpc.unary_stream_rpc_method_handler(
          servicer.Subscribe,
          request_deserializer=server__pb2.SubscribeRequest.FromString,
          response_serializer=server__pb2.ServerRequest.SerializeToString,
      ),
      'Unsubscribe': grpc.unary_unary_rpc_method_handler(
          servicer.Unsubscribe,
          request_deserializer=server__pb2.UnsubscribeRequest.FromString,
          response_serializer=server__pb2.UnsubscribeResponse.SerializeToString,
      ),
      'HandleVerify': grpc.unary_unary_rpc_method_handler(
          servicer.HandleVerify,
          request_deserializer=server__pb2.HandleVerifyRequest.FromString,
          response_serializer=server__pb2.HandleVerifyResponse.SerializeToString,
      ),
      'HandleIdentify': grpc.unary_unary_rpc_method_handler(
          servicer.HandleIdentify,
          request_deserializer=server__pb2.HandleIdentifyRequest.FromString,
          response_serializer=server__pb2.HandleIdentifyResponse.SerializeToString,
      ),
      'HandleGlobalAPB': grpc.unary_unary_rpc_method_handler(
          servicer.HandleGlobalAPB,
          request_deserializer=server__pb2.HandleGlobalAPBRequest.FromString,
          response_serializer=server__pb2.HandleGlobalAPBResponse.SerializeToString,
      ),
      'HandleUserPhrase': grpc.unary_unary_rpc_method_handler(
          servicer.HandleUserPhrase,
          request_deserializer=server__pb2.HandleUserPhraseRequest.FromString,
          response_serializer=server__pb2.HandleUserPhraseResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'server.Server', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
